package com.muyu.cloud.pay.domain.req;

import com.muyu.common.core.validation.custom.IsSystemYesNo;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Author：zhangchengzhi
 * @Package：com.muyu.cloud.pay.domain.req
 * @Project：cloud-pay
 * @name：OrderCustomerAddReq
 * @Date：2024/8/6 21:02
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Tag(name = "支付服务客户添加请求对象",description = "根据入参进行客户服务的添加")
public class OrderCustomerAddReq {

    /**
     * 客户名称
     */
@NotEmpty(message = "服务客户名称不可为空")
@Schema(title = "服务/客户名称", type = "String",defaultValue = "会员服务",
        description = "客户名称一般为微服务的中文名称,方便使用者进行区分",requiredProperties = {"appName"})
    private String  appName;


    /**
     * 客户编码
     */
@NotBlank(message = "服务客户编码不可为空")
@Schema(title = "服务/客户编码", type = "String",defaultValue = "muyu-vip",
        description = "客户编码,从[/customer/all]接口当中进行获取",requiredProperties = {"appCode"})

    private String appCode;


/**
 * 服务/客户描述
 */
@Schema(title = "服务/客户描述",type = "String")
private String appDesc;


/**
 * 状态
 */

@NotBlank(message = "客户使用状态不可为空")
@IsSystemYesNo
@Schema(title = "服务/客户开通状态", type = "String",defaultValue = "Y",
        description = "状态为Y和N,如果为Y则客户可以使用支付接口,若为N则客户不可以使用支付类接口")
private String status;


    /**
     * 客户备注
     */

    @Schema(title = "服务/客户备注",type = "String")
private String remark;






}
