package com.muyu.cloud.pay.domain.resp;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.common.core.annotation.Excel;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * @Author：zhangchengzhi
 * @Package：com.muyu.cloud.pay.domain.resp
 * @Project：cloud-pay
 * @name：CustomerListResp
 * @Date：2024/8/1 0:09
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Tag(name = "客户信息相应对象", description = "负责客户信息查询的响应结果")
public class CustomerResp {

    /**
     * 主键
     */
    @Excel(
            name = "用户序号",
            cellType = Excel.ColumnType.NUMERIC,
            prompt = "用户编号"
    )
    @Schema(description = "客户ID", defaultValue = "1", type = "Long")
    private Long id;

    /**
     * 服务/客户名称
     */
    @Excel(
            name = "客户名称"
    )
    @Schema(description = "客户名称", defaultValue = "商品服务", type = "String")
    private String appName;

    /**
     * 服务/客户编码
     */
    @Excel(
            name = "客户编码"
    )
    @Schema(description = "客户编码", defaultValue = "cloud_order", type = "String")
    private String appCode;


    /**
     * 状态
     */
    @Excel(
            name = "客户状态"
    )
    @Schema(description = "客户状态,同数据字典-系统是否", defaultValue = "Y", type = "String")
    private String status;
    @Excel(
            name = "创建人"
    )
    @Schema(description = "创建人", defaultValue = "muyu", type = "String")
    private String createBy;
    @Excel(
            name = "创建时间"
    )
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", defaultValue = "2024-8-1 0:22:36", type = "Date")
    private Date createTime;


    /**
     * 客户最近5条支付单
     */

    private List<CustomerOrderPaySimpleResp> orderPaySimpleRespList;


    /**
     * @param orderPayCustomer
     * @return 视图对象
     */

    public static CustomerResp customerBuild(OrderPayCustomer orderPayCustomer, Supplier<List<CustomerOrderPaySimpleResp>> function) {
        return CustomerResp.builder()
                .id(orderPayCustomer.getId())
                .appName(orderPayCustomer.getAppName())
                .appCode(orderPayCustomer.getAppCode())
                .status(orderPayCustomer.getStatus())
                .createBy(orderPayCustomer.getCreateBy())
                .createTime(orderPayCustomer.getCreateTime())
                .orderPaySimpleRespList(function.get())
                .build();

    }


}
