package com.muyu.cloud.pay.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.OrderPayInfo;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.domain.resp.CustomerResp;
import com.muyu.cloud.pay.mapper.OrderPayCustomerMapper;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.cloud.pay.service.OrderPayInfoService;
import com.muyu.common.core.enums.SystemYesNo;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.nacos.remote.service.NacosServerService;
import jakarta.annotation.Resource;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Author：zhangchengzhi
 * @Package：com.muyu.cloud.pay.service.impl
 * @Project：cloud-pay
 * @name：OrderPayCustomerServiceimpl
 * @Date：2024/7/30 20:54
 */
@Log4j2
@Service
public class OrderPayCustomerServiceImpl extends ServiceImpl<OrderPayCustomerMapper, OrderPayCustomer> implements OrderPayCustomerService {


    @Autowired
    private OrderPayInfoService orderPayService;

    @Resource
    private NacosServerService nacosServerService;

    @Override
    public List<CustomerResp> selectList(CustomerListReq customerListReq) {

        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();

        queryWrapper.like(StringUtils.isNotEmpty(customerListReq.getAppName()),
                OrderPayCustomer::getAppName, customerListReq.getAppName()
        );

        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppCode()),
                OrderPayCustomer::getAppCode, customerListReq.getAppCode()
        );

        queryWrapper.eq(
                StringUtils.isNotEmpty(customerListReq.getStatus()),
                OrderPayCustomer::getStatus, customerListReq.getStatus()
        );
        List<OrderPayCustomer> orderPayCustomerList = this.list(queryWrapper);

        return orderPayCustomerList.stream()
                .map(orderPayCustomer -> CustomerResp.customerBuild(
                        orderPayCustomer,
                        () -> orderPayService.selectOrderPayByAppAndLimit(orderPayCustomer.getAppCode(), 5)
                                .stream()
                                .map(OrderPayInfo::buildCustomerOrderPaySimpleResp)
                                .toList())
                )
                .toList();


    }

    @Override
    public List<String> getCustomerAllList() {
        List<String> naocsServiceAllList = nacosServerService.naocsServiceAllList();
        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.select(OrderPayCustomer::getAppCode);
        List<OrderPayCustomer> orderPayCustomerList = this.list(queryWrapper);
        Set<String> customerSet
                = orderPayCustomerList.stream().map(OrderPayCustomer::getAppCode).collect(Collectors.toSet());

        return naocsServiceAllList.stream()
                .filter(nacosServer -> !customerSet.contains(nacosServer))
                .toList();
    }

    @Override                  //禁用客户
    public void disable(Long orderCustomerId) {
        this.settingStatus(orderCustomerId, SystemYesNo.NO.getCode());
    }

    @Override           //启用客户
    public void enable(Long orderCustomerId) {
        this.settingStatus(orderCustomerId, SystemYesNo.YES.getCode());
    }

    public void settingStatus(Long orderCustomerId, String status) {
        UpdateWrapper<OrderPayCustomer> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", orderCustomerId).set("status", status);
        this.update(updateWrapper);
    }


    @Override
    public boolean save(OrderPayCustomer orderPayCustomer) {

        String appCode = orderPayCustomer.getAppCode();
        List<String> naocsServiceAllList = nacosServerService.naocsServiceAllList();
        log.info("进行服务合法性判断:[{}-->{}]", appCode, naocsServiceAllList);
        if (!naocsServiceAllList.contains(appCode)) {
            throw new ServiceException("客户编码违法");
        }

        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(OrderPayCustomer::getAppCode, appCode);
        long isAppCodeOnly = this.count(queryWrapper);
        log.info("进行服务code唯一性校验:[{}-{}]", appCode, isAppCodeOnly);
        if (this.count(queryWrapper) > 0) {
            throw new ServiceException("客户编码重复");
        }
        return super.save(orderPayCustomer);
    }


}
